@@ -31,13 +31,16 @@ def wait_for_jobs(backend: ShadeLocal, jobs: List[Jobs], paths: List[Path] = Non
     """
     Get all assets and check to make sure that each one of the jobs on the assets is either completed or failed
     """
+    print("Waiting for everything to be picked up on")
     wait_for_assets(backend, paths)
+    print("All assets in db!")
 
     job_keys = [job.value for job in jobs]
 
     def __asset_has_jobs(asset):
         for job in job_keys:
             if getattr(asset, job) not in ('COMPLETED', 'FAILED'):
+                print(f"Waiting for {job} on {asset.path}")
                 return False
         return True
 
